@@ -29,12 +29,12 @@
 #include "imageplugin.h"
 #include "digikam_export.h"
 
-class KAction;
+class TDEAction;
 
 class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_AdjustLevels : public Digikam::ImagePlugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
     
 public:
 
@@ -50,7 +50,7 @@ private slots:
 
 private:
 
-    KAction *m_levelsAction;
+    TDEAction *m_levelsAction;
 };
     
 #endif /* IMAGEPLUGIN_ADJUSTLEVELS_H */
