@@ -49,10 +49,10 @@ extern "C"
 
 // KDE includes.
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kurl.h>
-#include <kmessagebox.h>
-#include <kio/renamedlg.h>
+#include <tdemessagebox.h>
+#include <tdeio/renamedlg.h>
 #include <kstandarddirs.h>
 
 // Local includes.
@@ -938,9 +938,9 @@ void CameraController::customEvent(TQCustomEvent* e)
                         break;
                     }
 
-                    KIO::RenameDlg dlg(d->parent, i18n("Rename File"),
+                    TDEIO::RenameDlg dlg(d->parent, i18n("Rename File"),
                                        folder + TQString("/") + file, dest,
-                                       KIO::RenameDlg_Mode(KIO::M_MULTI | KIO::M_OVERWRITE | KIO::M_SKIP));
+                                       TDEIO::RenameDlg_Mode(TDEIO::M_MULTI | TDEIO::M_OVERWRITE | TDEIO::M_SKIP));
 
                     int result = dlg.exec();
                     dest       = dlg.newDestURL().path();
@@ -948,28 +948,28 @@ void CameraController::customEvent(TQCustomEvent* e)
 
                     switch (result)
                     {
-                        case KIO::R_CANCEL:
+                        case TDEIO::R_CANCEL:
                         {
                             cancel = true;
                             break;
                         }
-                        case KIO::R_SKIP:
+                        case TDEIO::R_SKIP:
                         {
                             skip = true;
                             break;
                         }
-                        case KIO::R_AUTO_SKIP:
+                        case TDEIO::R_AUTO_SKIP:
                         {
                             d->skipAll = true;
                             skip       = true;
                             break;
                         }
-                        case KIO::R_OVERWRITE:
+                        case TDEIO::R_OVERWRITE:
                         {
                             overwrite = true;
                             break;
                         }
-                        case KIO::R_OVERWRITE_ALL:
+                        case TDEIO::R_OVERWRITE_ALL:
                         {
                             d->overwriteAll = true;
                             overwrite       = true;
